@@ -22,12 +22,18 @@ def safedelete_manager_factory(manager_superclass, queryset_superclass, visibili
 
         def undelete(self):
             assert self.query.can_filter(), "Cannot use 'limit' or 'offset' with undelete."
-            self.all().update(deleted=False)
+            # TODO: Replace this by bulk update if we can (need to call pre/post-save signal)
+            for obj in self.all():
+                obj.undelete()
             self._result_cache = None
         undelete.alters_data = True
 
     class SafeDeleteManager(manager_superclass):
         def get_query_set(self):
+            # Deprecated in Django 1.7
+            return self.get_queryset()
+
+        def get_queryset(self):
             return self.all_with_deleted().filter(deleted=False)
 
         def all_with_deleted(self):
